==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/nastaveni/mzdy.php <==
<?php
/**
 * UTF8
 * Roman.Szablatura RON Software 05.03.2019
 */

namespace RonPortal\Settings;

use Ron\Controls\Preference;


return [
    'caption' => 'mzdy_nastaveni',
    'category' => 'nastaveni_sekce_mzdy',
    'name'  => 'mzdy',
    'index' => 400,
    'storage' => 'nastaveni',
    'strings' => 'preferences_mzdy.ini',
    'items' =>
        [
            [
                'type'  => Preference::CATEGORY,    'title' => 'dane_zadost'
            ],
            [
                'name'  => 'zadostizuctovanidanepoterminu',    'type'  => Preference::CHECKBOX,       'title' => 'zadost_podepsat_po_terminu',
                'infoText' => 'zadost_podepsat_po_terminu_info', 'defaultValue' => 0
            ],

            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_kontakt_mzdovy_pracovnik'
            ],
            [
                'name'  => 'danekontaktnamzdoveho',    'type'  => Preference::TEXT,       'title' => 'Mzdy_dane__kontakt_mzdovy_pracovnik',
                'infoText' => 'Mzdy_dane__kontakt_mzdovy_pracovnik_info', 'defaultValue' => 0
            ],

            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_prohlaseni_na_portale'
            ],
            [
                'name'  => 'povolitprohlaseninaportale',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_povolit_prohlaseni_na_portale',
                'infoText' => 'Mzdy_dane_povolit_prohlaseni_na_portale_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_pocatecni_rok',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_zobrazit_od_roku',
                'sql'   => 'SELECT DISTINCT {fn_YEAR(Rok)}, {fn_YEAR(Rok)} FROM RocniVyuctovaniDane ORDER BY 1 DESC',
                'defaultValue' => 2020
            ],
            [
                'name'  => 'dane_zjednoduseny_vzhled',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_zjednoduseny_vzhled',
                'infoText' => 'Mzdy_dane_zjednoduseny_vzhled_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_skryt_dalsiho_poplatnika',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_skryt_dalshiho_poplatnika',
                'infoText' => 'Mzdy_dane_skryt_dalshiho_poplatnika_info', 'defaultValue' => 0
            ],
            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_dokumenty'
            ],
            [
                'name'  => 'dane_dokumenty_deti_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_deti_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => ''
            ],
            [
                'name'  => 'dane_dokumenty_deti_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_odecet_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_odecitetelne_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => ''
            ],
            [
                'name'  => 'dane_dokumenty_odececet_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_partner_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_partner_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => ''
            ],
            [
                'name'  => 'dane_dokumenty_partner_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_kopirovat_popis',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_kopirovat_popis',
                'infoText' => 'Mzdy_dane_dokumenty_kopirovat_popis_info', 'defaultValue' => 0
            ],
            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_nerezident_kategorie'
            ],
            [
                'name'  => 'dane_nerezident_text_souhlasu',    'type'  => Preference::MEMO,       'title' => 'Mzdy_dane_nerezident_text_souhlasu',
                'infoText' => 'Mzdy_dane_nerezident_text_souhlasu_info'
            ],
        ]
];

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/nastaveni/mzdy.php <==
<?php
/**
 * UTF8
 * Roman.Szablatura RON Software 05.03.2019
 */

namespace RonPortal\Settings;

use Ron\Controls\Preference;


return [
    'caption' => 'mzdy_nastaveni',
    'category' => 'nastaveni_sekce_mzdy',
    'name'  => 'mzdy',
    'index' => 400,
    'storage' => 'nastaveni',
    'strings' => 'preferences_mzdy.ini',
    'items' =>
        [
            [
                'type'  => Preference::CATEGORY,    'title' => 'dane_zadost'
            ],
            [
                'name'  => 'daneterminvyplneni',    'type'  => Preference::TEXT,       'title' => 'Mzdy_dane_termin_vyplneni',
                'infoText' => 'Mzdy_dane_termin_vyplneni_info', 'defaultValue' => ''
            ],
            [
                'name'  => 'zadostizuctovanidanepoterminu',    'type'  => Preference::CHECKBOX,       'title' => 'zadost_podepsat_po_terminu',
                'infoText' => 'zadost_podepsat_po_terminu_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'danepocetzamestnavatelu',    'type'  => Preference::TEXT,       'title' => 'Mzdy_dane_pocet_zamestnavatelu',
                'defaultValue' => 3
            ],
            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_kontakt_mzdovy_pracovnik'
            ],
            [
                'name'  => 'danekontaktnamzdoveho',    'type'  => Preference::TEXT,       'title' => 'Mzdy_dane__kontakt_mzdovy_pracovnik',
                'infoText' => 'Mzdy_dane__kontakt_mzdovy_pracovnik_info', 'defaultValue' => 0
            ],

            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_prohlaseni_na_portale'
            ],
            [
                'name'  => 'povolitprohlaseninaportale',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_povolit_prohlaseni_na_portale',
                'infoText' => 'Mzdy_dane_povolit_prohlaseni_na_portale_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_pocatecni_rok',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_zobrazit_od_roku',
                'sql'   => 'SELECT DISTINCT {fn_YEAR(Rok)}, {fn_YEAR(Rok)} FROM RocniVyuctovaniDane ORDER BY 1 DESC',
                'defaultValue' => 2020
            ],
            [
                'name'  => 'dane_zjednoduseny_vzhled',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_zjednoduseny_vzhled',
                'infoText' => 'Mzdy_dane_zjednoduseny_vzhled_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_skryt_dalsiho_poplatnika',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_skryt_dalshiho_poplatnika',
                'infoText' => 'Mzdy_dane_skryt_dalshiho_poplatnika_info', 'defaultValue' => 0
            ],
            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_dokumenty'
            ],
            [
                'name'  => 'dane_dokumenty_deti_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_deti_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -2
            ],
            [
                'name'  => 'dane_dokumenty_deti_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_odecet_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_odecitetelne_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -3
            ],
            [
                'name'  => 'dane_dokumenty_odecet_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_partner_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_partner_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -4
            ],
            [
                'name'  => 'dane_dokumenty_partner_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
//            [
//                'name'  => 'dane_dokumenty_kopirovat_popis',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_kopirovat_popis',
//                'infoText' => 'Mzdy_dane_dokumenty_kopirovat_popis_info', 'defaultValue' => 0
//            ],
            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_vyuctovani_dokumenty' //vyuctovani
            ],
            [
                'name'  => 'dane_dokumenty_predchozizam_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_predchozizam_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -5
            ],
            [
                'name'  => 'dane_dokumenty_predchozizam_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_slevapartner_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_slevapartner_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -6
            ],
            [
                'name'  => 'dane_dokumenty_slevapartner_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_skolkovne_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_skolkovne_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -7
            ],
            [
                'name'  => 'dane_dokumenty_skolkovne_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_odecitatelne_typ',    'type'  => Preference::SQL_COMBOBOX,       'title' => 'Mzdy_dane_dokumenty_odecitatelne_polozky_typ',
                'sql'   => 'SELECT Kod, Popis FROM TypDokumentu WHERE KategorieDokumentu = 12 ORDER BY Kod',
                'defaultValue' => -8
            ],
            [
                'name'  => 'dane_dokumenty_odecitatelne_povinne',    'type'  => Preference::CHECKBOX,       'title' => 'Mzdy_dane_dokumenty_povinne',
                'infoText' => 'Mzdy_dane_dokumenty_povinne_info', 'defaultValue' => 0
            ],
            [
                'name'  => 'dane_dokumenty_maska',    'type'  => Preference::TEXT,       'title' => 'Mzdy_dane_dokumenty_maska',
                'infoText' => 'Mzdy_dane_dokumenty_maska_info', 'defaultValue' => '%TYPDOKUMENTU% %PORADOVECISLO%'
            ],
            [
                'type'  => Preference::CATEGORY,    'title' => 'Mzdy_dane_nerezident_kategorie'
            ],
            [
                'name'  => 'dane_nerezident_text_souhlasu',    'type'  => Preference::MEMO,       'title' => 'Mzdy_dane_nerezident_text_souhlasu',
                'infoText' => 'Mzdy_dane_nerezident_text_souhlasu_info'
            ],
        ]
];
